Attribute VB_Name = "modPtcUSB"
'**********************************************************
'*
'* File:        modPtcUSB.bas
'* Purpose:     Declare references to the external procedures in the
'*              Dynamic-Link-Libraries (DLL) ptcHid.dll and ptcSnd.dll
'* Date:        2010/04/26
'*
'* Copyright:   2010 PEI TEL Communications GmbH, Germany
'*
'* The prefix "ptcHid" shows that this is a function for the HID device
'* The prefix "ptcSnd" shows that this is a function for the Sound device
'**********************************************************

Option Explicit


'**********************************************************
'*
'* Function:    ptcHidGetVendorId
'* Purpose:     Reads the Vendor ID from the device
'* Parameters:  none
'* Returns:     Vendor ID
'*
'**********************************************************
Public Declare Function ptcHidGetVendorId Lib "ptcHid.dll" () As Long


'**********************************************************
'*
'* Function:    ptcHidGetProductId
'* Purpose:     Reads the Product ID from the device
'* Parameters:  none
'* Returns:     Product ID
'*
'**********************************************************
Public Declare Function ptcHidGetProductId Lib "ptcHid.dll" () As Long


'**********************************************************
'*
'* Function:    ptcHidGetVersionNumber
'* Purpose:     Reads the Revision Number from the device
'* Parameters:  none
'* Returns:     Revision Number
'*
'**********************************************************
Public Declare Function ptcHidGetVersionNumber Lib "ptcHid.dll" () As Long


'**********************************************************
'*
'* Function:    ptcHidGetSerialNumber
'* Purpose:     Reads the serial number from the device
'* Parameters:  none
'* Returns:     - Serial number. Refer to documentation for coding
'*              - If device not open: "" (Empty String)
'*
'**********************************************************
Public Declare Function ptcHidGetSerialNumber Lib "ptcHid.dll" () As String


'**********************************************************
'*
'* Function:    ptcHidGetDeviceName
'* Purpose:     Reads the device name from the device
'* Parameters:  none
'* Returns:     - Device name
'*              - If device not open: "" (Empty String)
'*
'**********************************************************
Public Declare Function ptcHidGetDeviceName Lib "ptcHid.dll" () As String


'**********************************************************
'*
'* Function:    ptcHidGetVendorName
'* Purpose:     Reads the vendor name from the device
'* Parameters:  none
'* Returns:     - Vendor name
'*              - If device not open: "" (Empty String)
'*
'**********************************************************
Public Declare Function ptcHidGetVendorName Lib "ptcHid.dll" () As String


'**********************************************************
'*
'* Function:    ptcHidGetDllVersion
'* Purpose:     Retrieves the DLL version of the DLL-file ptcHid.dll
'* Parameters:  none
'* Returns:     DLL version
'*
'**********************************************************
Public Declare Function ptcHidGetDllVersion Lib "ptcHid.dll" () As String


'**********************************************************
'*
'* Function:    ptcHidGetDllDate
'* Purpose:     Retrieves the date of the DLL-file ptcHid.dll
'* Parameters:  none
'* Returns:     DLL date
'*
'**********************************************************
Public Declare Function ptcHidGetDllDate Lib "ptcHid.dll" () As String


'**********************************************************
'*
'* Function:    ptcHidOpenDev
'* Purpose:     Opens the device
'* Parameters:  VID             - Vendor ID of the desired device
'*              PID             - Product ID of the desired device
'* Returns:     -1              - An open device has been unplugged
'*              0               - Device could not be opened. Possible reasons:
'*                                  -> The device does not exist
'*                                  -> The device is already open
'*              1               - Device could successfully be opened
'*
'**********************************************************
Public Declare Function ptcHidOpenDev Lib "ptcHid.dll" (ByVal VID As Long, ByVal PID As Long) As Long


'**********************************************************
'*
'* Function:    ptcHidCloseDev
'* Purpose:     Closes the previously opened device and cleans up. Must be
'*              called before leaving the application.
'* Parameters:  none
'* Returns:     0               - Closing was not sucessful. Possible reasons:
'*                                  -> The device is already closed
'*                                  -> There was no connection to a device
'*              1               - Connection to device could be successfully closed
'*
'**********************************************************
Public Declare Function ptcHidCloseDev Lib "ptcHid.dll" () As Long


'**********************************************************
'*
'* Function:    ptcHidGetInputReport
'* Purpose:     Reads an Input Report from the device
'* Parameters:  none
'* Returns:     Input Report    - Input Report of the opened device. Refer to DLL-documentation
'*                                for coding of the input report.
'*              -1              - No valid input report available. Possible Reasons:
'*                                  -> Device not open
'*
'**********************************************************
Public Declare Function ptcHidGetInputReport Lib "ptcHid.dll" () As Long


'**********************************************************
'*
'* Function:    ptcHidSetOutputReport
'* Purpose:     Sends an Output Report to the device
'* Parameters:  data            - Refer to DLL-documentation for coding of data
'* Returns:     0               - Command was not successful. Possible Reasons:
'*                                  -> Device not open
'*              1               - Command was sucessful
'*
'**********************************************************
Public Declare Function ptcHidSetOutputReport Lib "ptcHid.dll" (ByVal data As Integer) As Long






'**********************************************************
'*
'* Function:    ptcSndGetDllVersion
'* Purpose:     Retrieves the DLL version of the DLL-file ptcSnd.dll
'* Parameters:  none
'* Returns:     DLL version
'*
'**********************************************************
Public Declare Function ptcSndGetDllVersion Lib "ptcSnd.dll" () As String


'**********************************************************
'*
'* Function:    ptcSndGetDllDate
'* Purpose:     Retrieves the date of the DLL-file ptcSnd.dll
'* Parameters:  none
'* Returns:     DLL date
'*
'**********************************************************
Public Declare Function ptcSndGetDllDate Lib "ptcSnd.dll" () As String


'**********************************************************
'*
'* Function:    ptcSndGetWinVersion
'* Purpose:     Retrieves the Windows version
'* Parameters:  none
'* Returns:     Windows version
'*              - if the version can not be determined,
'*                "Unknown Version" will be returned
'*
'**********************************************************
Public Declare Function ptcSndGetWinVersion Lib "ptcSnd.dll" () As String


'**********************************************************
'*
'* Procedure:   ptcSndInitMixerEnum
'* Purpose:     Enumerate all mixers of system to find Mixer
'*              ID(s) for Playback and Recording. This function
'*              must be called once before any other call to a
'*              ptcSnd-Function
'* Parameters:  none
'* Returns:     none
'*
'**********************************************************
Public Declare Sub ptcSndInitMixerEnum Lib "ptcSnd.dll" ()



'**********************************************************
'*
'* Function:    ptcSndGetMasterVolume
'* Purpose:     Reads the current setting of master or waveout volume, depending
'*              on Operating System
'* Parameters:  none
'* Returns:     volume          - Current setting of volume in the range 0 ... 65535
'*              <0              - Command was not successful. Possible Reasons:
'*                                  -> No mixer available
'*                                  -> No access to control (depends on OS)
'*                                  -> ptcSndInitMixerEnum() not called prior to any
'*                                     call to a ptcSnd-function
'*
'**********************************************************
Public Declare Function ptcSndGetMasterVolume Lib "ptcSnd.dll" () As Long


'**********************************************************
'*
'* Function:    ptcSndSetMasterVolume
'* Purpose:     Sets the master volume
'* Parameters:  data            - Value for master volume in the range 0 ... 65535
'* Returns:     1               - Command was successful
'*              <=0             - Command was not successful. Possible Reasons:
'*                                  -> No mixer available
'*                                  -> No access to control (depends on OS)
'*                                  -> ptcSndInitMixerEnum() not called prior to any
'*                                     call to a ptcSnd-function
'*
'**********************************************************
Public Declare Function ptcSndSetMasterVolume Lib "ptcSnd.dll" (ByVal data As Long) As Long


'**********************************************************
'*
'* Function:    ptcSndGetMicVolume
'* Purpose:     Reads the current setting of the microphone (capture) volume
'* Parameters:  none
'* Returns:     volume          - Current setting of volume in the range 0 ... 65535
'*              <0              - Command was not successful. Possible Reasons:
'*                                  -> No mixer available
'*                                  -> No access to control (depends on OS)
'*                                  -> ptcSndInitMixerEnum() not called prior to any
'*                                     call to a ptcSnd-function
'*
'**********************************************************
Public Declare Function ptcSndGetMicVolume Lib "ptcSnd.dll" () As Long


'**********************************************************
'*
'* Function:    ptcSndSetMicVolume
'* Purpose:     Sets the microphone volume
'* Parameters:  data            - Value for mic volume in the range 0 ... 65535
'* Returns:     1               - Command was successful
'*              <=0             - Command was not successful. Possible Reasons:
'*                                  -> No mixer available
'*                                  -> No access to control (depends on OS)
'*                                  -> ptcSndInitMixerEnum() not called prior to any
'*                                     call to a ptcSnd-function
'**********************************************************
Public Declare Function ptcSndSetMicVolume Lib "ptcSnd.dll" (ByVal data As Long) As Long


'**********************************************************
'*
'* Function:    ptcSndSetMicVolumeMute
'* Purpose:     Mutes/Unmutes the microphone
'* Parameters:  mute            - 0     -> unmute the microphone
'*                              - 1     -> mute the microphone
'* Returns:     1               - Command was successful
'*              <=0             - Command was not successful. Possible Reasons:
'*                                  -> No mixer available
'*                                  -> No access to control (depends on OS)
'*                                  -> ptcSndInitMixerEnum() not called prior to any
'*                                     call to a ptcSnd-function
'*
'**********************************************************
Public Declare Function ptcSndSetMicVolumeMute Lib "ptcSnd.dll" (ByVal mute As Long) As Long


'**********************************************************
'*
'* Function:    ptcSndGetMicVolumeMute
'* Purpose:     Reads current mute state of microphone (capture)
'* Parameters:  none
'* Returns:     0               - Microphone is unmuted
'*              1               - Microphone is muted
'*              <0              - Command was not successful. Possible Reasons:
'*                                  -> No mixer available
'*                                  -> No access to control (depends on OS)
'*                                  -> ptcSndInitMixerEnum() not called prior to any
'*                                     call to a ptcSnd-function
'*
'**********************************************************
Public Declare Function ptcSndGetMicVolumeMute Lib "ptcSnd.dll" () As Long


'**********************************************************
'*
'* Function:    ptcSndSetVolumeMute
'* Purpose:     Mutes/Unmutes the loudspeaker
'* Parameters:  mute            - 0     -> Unmute the loudspeaker
'*                              - 1     -> Mute the loudspeaker
'* Returns:     1               - Command was successful
'*              <=0             - Command was not successful. Possible Reasons:
'*                                  -> No mixer available
'*                                  -> No access to control (depends on OS)
'*                                  -> ptcSndInitMixerEnum() not called prior to any
'*                                     call to a ptcSnd-function
'*
'**********************************************************
Public Declare Function ptcSndSetVolumeMute Lib "ptcSnd.dll" (ByVal mute As Long) As Long


'**********************************************************
'*
'* Function:    ptcSndGetVolumeMute
'* Purpose:     Reads current mute state of loudspeaker
'* Parameters:  none
'* Returns:     0               - Loudspeaker is unmuted
'*              1               - Loudspeaker is muted
'*              <0              - Command was not successful. Possible Reasons:
'*                                  -> No mixer available
'*                                  -> No access to control (depends on OS)
'*                                  -> ptcSndInitMixerEnum() not called prior to any
'*                                     call to a ptcSnd-function
'*
'**********************************************************
Public Declare Function ptcSndGetVolumeMute Lib "ptcSnd.dll" () As Long


'Windows API declarations (Refer to Windows MSDN documentation for detailed information)
Public Declare Function LoadLibrary Lib "kernel32" Alias "LoadLibraryA" (ByVal lpLibFileName As String) As Long
Public Declare Function FreeLibrary Lib "kernel32" (ByVal hLibModule As Long) As Long


'Vendor ID and Product ID for PEI TEL USB devices
Public Const MyVID As Long = &H74D
Public Const MyPID As Long = &H3576


'Constants used for ptcDevOpen
Public Const PLUGGED_OPEN As Integer = 1
Public Const UNPLUGGED As Integer = -1


'Constants used for ptcGetInputReport
Public Const MASK_EXT_HEADSET = &H4
Public Const MASK_EXT_POWER = &H8
Public Const MASK_CENTER_BUTTON = &H10
Public Const MASK_LEFT_BUTTON = &H20
Public Const MASK_EXT_BUTTON = &H40
Public Const MASK_RIGHT_BUTTON = &H80


'Constants for LEDs and Outputs
Public Const SET_LEFT_LED = &H1
Public Const SET_CENTER_LED = &H2
Public Const SET_RIGHT_LED = &H4
Public Const SET_SPK = &H8
Public Const SET_MUTE = &H40


'Enumeration for currently available or planned PEI TEL USB devices
Public Enum enPtcDevices
    enNoDevice
    enPS12USB
    enPS20USB
    enME_TM
    enHA_AXX
    enDEVKIT
End Enum


